<div class="card">
    <h5 class="card-header">Linux Volumes</h5>
    <div class="card-body">
        {% if partitions %}
        <table class="table table-hover">
            <tr>
                <td>Volume Name</td>
                <td>Filesystem</td>
                <td>Mount Path</td>
                <td>Volume Size</td>
                <td>Partition Name</td>
                <td>Partition Type</td>
                <td>Partition Size</td>
                <td>Drive Identifier</td>
            </tr>
            {% for partition in partitions %}
            <tr>
                <td>@TODO vg_docker-lv_docker</td>
                <td>@TODO ext4</td>
                <td>@TODO /var/lib/docker</td>
                <td>{{ partition.device }}</td>
                <td>{{ partition.type }}</td>
                <td>{{ partition.size }}</td>
                <td>{{ partition.drive.identifier|linkify|placeholder }}<br> ({{ partition.drive.size }} GB, {{ partition.drive.cluster|linkify|placeholder }})</td>
            </tr>
            {% endfor %}
            {% for physical_volume in physical_volumes %}
            <tr>
                <td>{{ physical_volume.vg }}- @TODO lv_docker</td>
                <td>@TODO ext4</td>
                <td>@TODO /var/lib/docker</td>
                <td>{{ physical_volume.pv_name }}</td>
            </tr>
            {% endfor %}
            {% for logical_volume in logical_volumes %}
            <tr>
                <td>@TODO {{ logical_volume.lv_name|linkify|placeholder }}</td>
                <td>{{ logical_volume.fs|linkify|placeholder }}</td>
                <td>{{ logical_volume.path|linkify|placeholder }}</td>
                <td>{{ logical_volume.size|linkify|placeholder }}</td>
            </tr>
            {% endfor %}
        </table>
        {% else %}
        <div class="text-muted">None</div>
        {% endif %}
    </div>
    <div class="card-footer text-end noprint">
        <a href="{% url 'plugins:netbox_storage:drive_add' %}" class="btn btn-sm btn-primary">
            <span class="mdi mdi-plus-thick" aria-hidden="true"></span> Add Drive
        </a>
    </div>
</div>